@@ -6,12 +6,12 @@
 #include <QMainWindow>
 #include <QProcess>
 #include <QSettings>
-#include <QMessageBox>
 #include <QShortcut>
 
 #include "ui_applicationswindow.h"
 #include "descriptivedelegate.h"
 #include "applicationdialog.h"
+#include "confirmdialog.h"
 
 namespace Ui {
     class ApplicationsWindow;
