@@ -4,7 +4,7 @@
 
 int FileOperation::idCounter = 0;
 
-FileOperation::FileOperation()
+FileOperation::FileOperation(Type type, QFileInfoList files, QFileInfo targetDir)
 {
     id = idCounter++;
 
@@ -14,13 +14,12 @@ FileOperation::FileOperation()
     overwriteAction = Ask;
     selfOverwriteAction = Ask;
     errorAction = Ask;
-}
 
-// Set the files for operation to process
-void FileOperation::setFiles(QFileInfoList files)
-{
-    if (state() == Initial)
-        this->files = files;
+    this->type = type;
+    this->files = files;
+    this->targetDir = targetDir;
+
+    reportProgress(0, tr("%n item(s)", "", files.size()), targetDir.absoluteFilePath());
 }
 
 // Free operation details
@@ -369,42 +368,6 @@ bool FileOperation::rest()
     }
 }
 
-// Execute the file-copying thread
-void FileOperation::copy(QFileInfo targetDir)
-{
-    this->targetDir = targetDir;
-    this->type = Copy;
-
-    start();
-}
-
-// Execute the file-moving thread
-void FileOperation::move(QFileInfo targetDir)
-{
-    this->targetDir = targetDir;
-    this->type = Move;
-
-    start();
-}
-
-// Execute the file-linking thread
-void FileOperation::link(QFileInfo targetDir)
-{
-    this->targetDir = targetDir;
-    this->type = Link;
-
-    start();
-}
-
-// Execute the file-deleting thread
-void FileOperation::remove()
-{
-    this->targetDir = QFileInfo();
-    this->type = Remove;
-
-    start();
-}
-
 // Perform copying or moving
 void FileOperation::runCopyOrMove()
 {
