@@ -14,6 +14,7 @@
 #define DEFAULT_HideLocationBar false
 #define DEFAULT_FirstDetail FileSystemModel::Size
 #define DEFAULT_SecondDetail FileSystemModel::Date
+#define DEFAULT_Sorting QDir::Name
 
 // Clipboard
 #define DEFAULT_SelectNewItems true
@@ -23,5 +24,7 @@
 
 // Operations
 #define DEFAULT_ArchiveSize 10
+#define DEFAULT_ActiveLimiter false
+#define DEFAULT_MaxActive 1
 
 #endif // GLOBAL_H
