@@ -23,10 +23,12 @@ public:
     void remove(int id);
     void setAttentionAction(int id, FileOperation::Action, QString hint = QString());
 
-    void setArchiveSize(int size);
+    void setActiveLimit(int activeLimit);
+    void setArchiveSize(int archiveSize);
     void clearArchive();
 
     QList<FileOperation*> activeOperations;
+    QList<FileOperation*> queuedOperations;
     QList<FileOperation*> archivalOperations;
 
 signals:
@@ -43,9 +45,13 @@ private:
     static OperationManager *instance;
 
     FileOperation* findActiveById(int id);
+
     void cleanArchive();
     int archiveSize;
 
+    void fillQueue();
+    int activeLimit;
+
 private slots:
     void onStateChanged(int state);
     void onProgressChanged(int progress, QString source, QString target);
